use serde::{Deserialize, Serialize};

use std::fs::File;

#[derive(Default, Serialize, Deserialize)]
pub struct Config {
	pub homeserver_url: String,
	pub username: String,
	pub password: String,
	pub store_path: String,
	pub statsd_server: String,
}

pub fn get_config() -> Config {
	let file = get_conf_file();
	let json: serde_json::Value = serde_json::from_reader(file).unwrap();
	serde_json::from_value(json).unwrap()
}

fn get_conf_file() -> File {
	let filenames = ["config.json", "/etc/cat_disruptor_7000/config.json"];
	for filename in filenames.iter() {
		match File::open(filename) {
			Ok(x) => return x,
			Err(_) => continue,
		}
	}

	panic!("Could not open config file");
}
