use std::path::PathBuf;

use rusqlite::{params, Connection};

pub struct DataStore {
	conn: Connection,
}

impl DataStore {
	pub fn open(filename: PathBuf) -> Self {
		let conn = Connection::open(filename).unwrap();

		conn.execute(
			"CREATE TABLE IF NOT EXISTS device_ids (
            id INTEGER PRIMARY KEY,
            device_id VARCHAR(10) NOT NULL UNIQUE
        )",
			params![],
		)
		.unwrap();

		DataStore { conn }
	}

	pub fn get_device_id(&self) -> Option<String> {
		match self.conn.query_row(
			"SELECT device_id FROM device_ids ORDER BY id DESC LIMIT 1",
			params![],
			|x| x.get(0),
		) {
			Ok(x) => Some(x),
			Err(_) => None,
		}
	}

	pub fn save_device_id(&self, device_id: String) {
		self.conn
			.execute(
				"INSERT OR IGNORE INTO device_ids (device_id) VALUES (?1)",
				params![device_id],
			)
			.unwrap();
	}
}
