use matrix_sdk::{
	events::EventType,
	identifiers::{EventId, RoomId},
	Client,
};
use ruma::api::client::r0::message::create_message_event;
use serde::{Deserialize, Serialize};
use std::collections::HashMap;
use uuid::Uuid;

#[derive(Clone, Serialize, Deserialize, Debug)]
struct ContentStruct {
	pub rel_type: String,
	pub event_id: EventId,
	pub key: String,
}

pub async fn react(
	client: &Client,
	event_id: EventId,
	room_id: RoomId,
	emoji: String,
) -> Result<(), String> {
	let mut content_hm: HashMap<String, ContentStruct> = HashMap::new();
	content_hm.insert(
		"m.relates_to".to_string(),
		ContentStruct {
			rel_type: "m.annotation".to_string(),
			event_id,
			key: emoji,
		},
	);

	let request = create_message_event::Request {
		event_type: EventType::Custom("m.reaction".into()),
		room_id,
		txn_id: Uuid::new_v4().to_string(),
		data: serde_json::value::to_raw_value(&content_hm).unwrap(),
	};

	match client.send(request).await {
		Ok(_) => Ok(()),
		Err(x) => Err(format!("{}", x)),
	}
}
